@@ -67,6 +67,9 @@ addtable2plot<-function(x,y=NULL,table,lwd=par("lwd"),bty="n",
    xleft<-xleft+rowname.width
   }
   for(column in 1:tabdim[2]) {
+   rect(xleft,ytop-(row+display.colnames-1)*cellheight,
+    xleft+cellwidth[column],ytop-(row+display.colnames)*cellheight,
+    col=bg[row,column])
    text(xleft+0.5*cellwidth[column],
     ytop-(row+display.colnames-0.5)*cellheight,
     table[row,column],cex=cex,col=text.col)
@@ -87,9 +90,10 @@ addtable2plot<-function(x,y=NULL,table,lwd=par("lwd"),bty="n",
    xleft+sum(cellwidth),
    ytop-display.colnames*cellheight-cumsum(rep(cellheight,tabdim[1]-1)))
  }
+ if(bty == "n")
+  rect(xleft,ytop-nvcells*cellheight,xleft+sum(cellwidth),
+   ytop-cellheight*display.colnames,lwd=lwd,border=box.col)
  if(!is.null(title)) {
-  if(bty=="n")
-   segments(xleft,ytop,xleft+sum(cellwidth)+rowname.width,ytop,lwd=lwd,col=box.col)
   xleft<-x-xjust*(sum(cellwidth)+rowname.width)
   text(xleft+(rowname.width+sum(cellwidth))/2,ytop+cellheight/2,title,
    cex=cex,col=text.col)
